# Generated by Django 4.0.3 on 2022-03-01 17:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('user_notifications', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='notification',
            name='display_type',
            field=models.IntegerField(choices=[(100, 'Bootstrap Alert'), (200, 'Modal Info'), (201, 'Modal Form')], default=100, verbose_name='Message Type'),
        ),
    ]
